Description Usage Arguments Details Value See Also Examples
Open a new logfile
1 2 |
scriptname |
Name of script (and thus logfile) |
loglevel |
Minimum priority level (numeric, optional) |
logfile |
Override default logfile (character or |
append |
Append to logfile? (logical, optional) |
sink |
Send all console output to logfile? (logical, optional) |
Open a new logfile. If sink is TRUE (the default), all
screen output will be captured (via sink).
Re-opening a logfile will erase the previous output unless append
is TRUE. Note that messages will only appear in the logfile if their
level exceeds loglevel; this allows you to easily change
the amount of detail being logged.
Invisible fully-qualified name of log file
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.